/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */
package com.openexchange.usm.connector.commands;

import static com.openexchange.usm.connector.commands.CommandConstants.END_SYNCHRONIZATION;
import static com.openexchange.usm.connector.commands.CommandConstants.SESSIONID;
import javax.servlet.http.HttpServletRequest;
import com.openexchange.usm.api.exceptions.USMException;
import com.openexchange.usm.json.ConnectorBundleErrorCodes;
import com.openexchange.usm.json.HttpSessionUtil;
import com.openexchange.usm.json.USMJSONAPIException;
import com.openexchange.usm.json.USMJSONServlet;
import com.openexchange.usm.json.response.ResponseObject;
import com.openexchange.usm.json.response.ResponseStatusCode;
import com.openexchange.usm.util.TempFileStorage;

/**
 * Handler for the Logout USM-JSON-Command.
 * @author ldo
 *
 */
public class LogoutHandler extends NormalCommandHandler {
	private static final String[] REQUIRED_PARAMETERS = { SESSIONID };
	private static final String[] OPTIONAL_PARAMETERS = { END_SYNCHRONIZATION };

    public LogoutHandler(USMJSONServlet servlet, HttpServletRequest request) throws USMJSONAPIException {
        super(servlet, request);
	}

	@Override
	public ResponseObject handleRequest() throws USMJSONAPIException {
	    HttpSessionUtil.removeSession(getHttpSession(), getStringParameter(SESSIONID));
		if (getBooleanParameter(END_SYNCHRONIZATION)) {
			try {
				_session.endSyncronization();
			} catch (USMException e) {
				throw USMJSONAPIException.createInternalError(
						ConnectorBundleErrorCodes.LOGOUT_END_SYNCHRONIZATION_FAILED, e);
			}
		}
		return new ResponseObject(ResponseStatusCode.SUCCESS);
	}

	@Override
	protected String[] getOptionalParameters() {
		return OPTIONAL_PARAMETERS;
	}

	@Override
	protected String[] getRequiredParameters() {
		return REQUIRED_PARAMETERS;
	}

    @Override
    public void disposeResources() {
        if (_session != null)
            TempFileStorage.deleteTempFiles(_session);
    }
}
