/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */
package com.openexchange.usm.connector.sync;

import com.openexchange.usm.api.contenttypes.common.ContentType;
import com.openexchange.usm.api.session.DataObject;

public class ContactSorter extends DataObjectSorter {

    private final int _displayNameIndex;
    private final int _distributionListIndex;

	public ContactSorter(ContentType contentType) {
		_displayNameIndex = getFieldIndex(contentType, "display_name");
        _distributionListIndex = getFieldIndex(contentType, "mark_as_distributionlist");
	}

	@Override
    public int compare(DataObject o1, DataObject o2) {
	    int compareDistributionList = compareBoolean(o1, o2, _distributionListIndex);
	    if (compareDistributionList == 0)
	        return compareString(o1, o2, _displayNameIndex);
	    // sort contacts before distribution lists
        return compareDistributionList;
	}
}
